@@ -88,15 +88,15 @@ if ! function_exists echo_summary; then
     }
 fi
 
-echo_summary "monasca's post_test_hook.sh was called..."
+echo_summary "monasca-log's post_test_hook.sh was called..."
 (set -o posix; set)
 
 # save ref to monasca-api dir
 export MONASCA_LOG_API_DIR="$BASE/new/monasca-log-api"
 export TEMPEST_DIR="$BASE/new/tempest"
 
-sudo chown -R jenkins:stack $MONASCA_LOG_API_DIR
-sudo chown -R jenkins:stack $TEMPEST_DIR
+sudo chown -R "${USER}":stack $MONASCA_LOG_API_DIR
+sudo chown -R "${USER}":stack $TEMPEST_DIR
 
 load_devstack_utilities
 setup_monasca_log
